@@ -180,21 +180,24 @@ class Qimai_Outside_Tool:
 
 # 计算七麦内的备用工具；
 class Qimai_Intside_Tool:
-    def rank_ios10_type(self, price):
-        if price == '0.00' or price == '免费':
+    def __init__(self, data_info):
+        self.data_info = data_info
+
+    def rank_ios10_type(self):
+        if self.data_info == '0.00' or self.data_info == '免费':
             return '总榜(免费)'
         else:
             return '总榜(付费)'
 
-    def old_rank_num(self, rank_data, rank_name='总榜(免费)'):
-        for app_rank in rank_data['data']['list']:
+    def old_rank_num(self, rank_name='总榜(免费)'):
+        for app_rank in self.data_info['data']['list']:
             if app_rank['name'] == rank_name:
                 return app_rank['data'][0][0]
         else:
             return 0
 
-    def new_rank_num(self, rank_data, rank_name='总榜(免费)'):
-        for app_rank in rank_data['data']['list']:
+    def new_rank_num(self, rank_name='总榜(免费)'):
+        for app_rank in self.data_info['data']['list']:
             if app_rank['name'] == rank_name:
                 return app_rank['data'][-1][0]
         else:
@@ -325,22 +328,38 @@ class Get_Keyword_Info(Qimai_Diy_Var):
         self.keyword = keyword
 
     def get_keyword_search(self):
-        url = 'https://api.qimai.cn/search/getWordInfo?country=%s&device=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.country, self.device, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
+        url = 'https://api.qimai.cn/search/index?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
         res = session.get(url, headers=headers)
         self.keyword_serch_index = res.json()
         return self.keyword_serch_index
 
     def get_keyword_wordinfo(self):
-        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
+        url = 'https://api.qimai.cn/search/getWordInfo?country=%s&device=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' % (self.country, self.device, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time - self.one_day)
         res = session.get(url, headers=headers)
         self.keyword_WordInfo = res.json()
         return self.keyword_WordInfo
 
+    def get_top_to_df(self, top_num=100):
+        self.get_keyword_search()
+        keyword_top_list = []
+        run_num = 1
+        for ky_search in self.keyword_serch_index['appList']:
+            if ky_search['kind'] == 'software' and run_num <= top_num:
+                keyword_top_list.append(ky_search['appInfo'])
+                run_num += 1
+        self.keyword_top_df = Qimai_Outside_Tool(keyword_top_list).json_to_df()
+        return self.keyword_top_df
+
     def get_keyword_hints(self):
         self.get_keyword_wordinfo()
         self.hints = self.keyword_WordInfo['wordInfo']['hints']
         return self.hints
 
+    def get_keyword_results(self):
+        self.get_keyword_wordinfo()
+        self.results = self.keyword_WordInfo['wordInfo']['search_no']
+        return self.results
+
 # 获取产品的关键词相关数据；
 class Get_App_Keyword(Qimai_Diy_Var):
     def __init__(self, appid):
