@@ -1,6 +1,5 @@
 import random,os
 from multiprocessing.pool import Pool
-from qm_spider import *
 from qm_spider.top_keyword import *
 from qm_spider.threading_py import *
 
@@ -38,7 +37,7 @@ def top_keyword_multiprocessing(appid_list, keyword_hot_start, start_time, end_t
 
 def multiprocessing_run(appid, keyword_hot_start, start_time, end_time, file_path):
     appname = Get_App_Appinfo(appid).get_subname()
-    print("【%s】子进程开始，进程ID：%d\n" % (appname, os.getpid()))
+    print("【%s】子进程开始，进程ID：%d" % (appname, os.getpid()))
     old_seconds = datetime.datetime.now()
     Get_Top_Keyword(appid, keyword_hot_start, start_time, end_time).df_to_excel(file_path)
     now_seconds = datetime.datetime.now()
