@@ -12,7 +12,7 @@ class Top_Keyword_Thread(threading.Thread):
         self.name = Get_App_Appinfo(args[0]).get_subname()
         self.args = args
 
-    def Thread_run(self):
+    def run(self):
         print ("===开启 %s 数据获取线程===" %(self.name))
         # 获取锁，用于线程同步
         threadLock.acquire()
